==> commons-cli-1.9.0-src.tar.gz: commons-cli-1.9.0-src/src/test/java/org/apache/commons/cli/bug/BugCLI252Test.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.commons.cli.bug;

import static org.junit.jupiter.api.Assertions.assertThrows;

import org.apache.commons.cli.AmbiguousOptionException;
import org.apache.commons.cli.DefaultParser;
import org.apache.commons.cli.Option;
import org.apache.commons.cli.Options;
import org.apache.commons.cli.ParseException;
import org.junit.jupiter.api.Test;

public class BugCLI252Test {

    private Options getOptions() {
        final Options options = new Options();
        options.addOption(Option.builder().longOpt("prefix").build());
        options.addOption(Option.builder().longOpt("prefixplusplus").build());
        return options;
    }

    @Test
    public void testAmbiquousOptionName() {
        assertThrows(AmbiguousOptionException.class, () ->
                new DefaultParser().parse(getOptions(), new String[]{"--pref"})
        );
    }

    @Test
    public void testExactOptionNameMatch() throws ParseException {
        new DefaultParser().parse(getOptions(), new String[] {"--prefix"});
    }

}

==> commons-cli-1.10.0-src.tar.gz: commons-cli-1.10.0-src/src/test/java/org/apache/commons/cli/bug/BugCLI252Test.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.commons.cli.bug;

import static org.junit.jupiter.api.Assertions.assertThrows;

import org.apache.commons.cli.AmbiguousOptionException;
import org.apache.commons.cli.DefaultParser;
import org.apache.commons.cli.Option;
import org.apache.commons.cli.Options;
import org.apache.commons.cli.ParseException;
import org.junit.jupiter.api.Test;

class BugCLI252Test {

    private Options getOptions() {
        final Options options = new Options();
        options.addOption(Option.builder().longOpt("prefix").get());
        options.addOption(Option.builder().longOpt("prefixplusplus").get());
        return options;
    }

    @Test
    void testAmbiquousOptionName() {
        assertThrows(AmbiguousOptionException.class, () ->
                new DefaultParser().parse(getOptions(), new String[]{"--pref"})
        );
    }

    @Test
    void testExactOptionNameMatch() throws ParseException {
        new DefaultParser().parse(getOptions(), new String[] {"--prefix"});
    }

}
